import {
  select,
  geoPath,
  geoNaturalEarth1,
  zoom,
  event,
  scaleOrdinal,
  schemeRdPu
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

const colorLegendG = svg.append('g')
    .attr('transform', `translate(40,310)`);

g.append('path')
    .attr('class', 'sphere')
    .attr('d', pathGenerator({type: 'Sphere'}));

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));

const colorScale = scaleOrdinal();

const colorValue = d => +d.properties['P2P'];

loadAndProcessData().then(countries => {
  
  colorScale
    .domain(countries.features.map(colorValue))
    .domain(colorScale.domain([1.8,2.7, 4.1, 6.1, 10]).reverse())
    .range(schemeRdPu[colorScale.domain([1.8,2.7, 4.1, 6.1, 10]).length]);
  
  colorLegendG.call(colorLegend, {
    colorScale,
    circleRadius: 8,
    spacing: 20,
    textOffset: 12,
    backgroundRectWidth: 150
  });
  
  g.selectAll('path').data(countries.features)
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
      .attr('fill', d => isNaN(d.properties['rank'])
        ? '#D0D3D4':[colorScale(colorValue(d))]
           )
    .append('title')
      .text(d =>  isNaN(d.properties['rank'])
        ? 'Missing data'
        : [d.properties.country + ': ' +  colorValue(d) + ': Rank ' + d.properties['rank']]);
  
});